@@ -188,9 +188,11 @@ def get_legistar_events_for_timespan(
     return response
 
 
-def stripped(input_str: str) -> str:
+def str_simplified(input_str: str) -> str:
     """
-    Return leading and trailing whitespace removed if it is a string
+    Remove leading/trailing whitespaces,
+    simplify multiple whitespaces,
+    unify newline characters
 
     Parameters
     ----------
@@ -201,8 +203,15 @@ def stripped(input_str: str) -> str:
     str
         input_str stripped if it is a string
     """
-    if isinstance(input_str, str):
-        return input_str.strip()
+    if not isinstance(input_str, str):
+        return input_str
+
+    input_str = input_str.strip()
+    # unify newline to \n
+    input_str = re.sub(r"[\r\n\f]+", r"\n", input_str)
+    # multiple spaces and tabs to 1 space
+    input_str = re.sub(r"([ \t\v])+", r"\1", input_str)
+
     return input_str
 
 
@@ -417,7 +426,7 @@ class LegistarScraper:
             if legistar_ev[LEGISTAR_SESSION_VIDEO_URI]:
                 list_uri = [
                     {
-                        CDP_VIDEO_URI: stripped(
+                        CDP_VIDEO_URI: str_simplified(
                             legistar_ev[LEGISTAR_SESSION_VIDEO_URI]
                         ),
                         CDP_CAPTION_URI: None,
@@ -447,9 +456,9 @@ class LegistarScraper:
             ingestion_models.append(
                 self.get_none_if_empty(
                     EventIngestionModel(
-                        agenda_uri=stripped(legistar_ev[LEGISTAR_AGENDA_URI]),
-                        minutes_uri=stripped(legistar_ev[LEGISTAR_MINUTES_URI]),
-                        body=Body(name=stripped(legistar_ev[LEGISTAR_BODY_NAME])),
+                        agenda_uri=str_simplified(legistar_ev[LEGISTAR_AGENDA_URI]),
+                        minutes_uri=str_simplified(legistar_ev[LEGISTAR_MINUTES_URI]),
+                        body=Body(name=str_simplified(legistar_ev[LEGISTAR_BODY_NAME])),
                         sessions=sessions,
                         event_minutes_items=self.get_event_minutes(
                             legistar_ev[LEGISTAR_EV_ITEMS]
@@ -460,7 +469,7 @@ class LegistarScraper:
 
         # easier for calling pipeline to handle an empty list rather than None
         # so request reduced_list() to give me [], not None
-        return reduced_list(ingestion_models, collapse=True)
+        return reduced_list(ingestion_models, collapse=False)
 
     def get_video_uris(self, legistar_ev: Dict) -> List[Dict]:
         """
@@ -713,11 +722,11 @@ class LegistarScraper:
         """
         return self.get_none_if_empty(
             Person(
-                email=stripped(legistar_person[LEGISTAR_PERSON_EMAIL]),
+                email=str_simplified(legistar_person[LEGISTAR_PERSON_EMAIL]),
                 external_source_id=legistar_person[LEGISTAR_PERSON_EXT_ID],
-                name=stripped(legistar_person[LEGISTAR_PERSON_NAME]),
-                phone=stripped(legistar_person[LEGISTAR_PERSON_PHONE]),
-                website=stripped(legistar_person[LEGISTAR_PERSON_WEBSITE]),
+                name=str_simplified(legistar_person[LEGISTAR_PERSON_NAME]),
+                phone=str_simplified(legistar_person[LEGISTAR_PERSON_PHONE]),
+                website=str_simplified(legistar_person[LEGISTAR_PERSON_WEBSITE]),
                 is_active=bool(legistar_person[LEGISTAR_PERSON_ACTIVE]),
             )
         )
@@ -769,8 +778,8 @@ class LegistarScraper:
                 self.get_none_if_empty(
                     SupportingFile(
                         external_source_id=attachment[LEGISTAR_FILE_EXT_ID],
-                        name=stripped(attachment[LEGISTAR_FILE_NAME]),
-                        uri=stripped(attachment[LEGISTAR_FILE_URI]),
+                        name=str_simplified(attachment[LEGISTAR_FILE_NAME]),
+                        uri=str_simplified(attachment[LEGISTAR_FILE_URI]),
                     )
                 )
                 for attachment in legistar_ev_attachments
@@ -807,11 +816,11 @@ class LegistarScraper:
                 external_source_id=legistar_ev[LEGISTAR_MATTER_EXT_ID],
                 # Too often EventItemMatterName is not filled
                 # but EventItemMatterFile is
-                name=stripped(legistar_ev[LEGISTAR_MATTER_NAME])
-                or stripped(legistar_ev[LEGISTAR_MATTER_TITLE]),
-                matter_type=stripped(legistar_ev[LEGISTAR_MATTER_TYPE]),
+                name=str_simplified(legistar_ev[LEGISTAR_MATTER_NAME])
+                or str_simplified(legistar_ev[LEGISTAR_MATTER_TITLE]),
+                matter_type=str_simplified(legistar_ev[LEGISTAR_MATTER_TYPE]),
                 sponsors=sponsors,
-                title=stripped(legistar_ev[LEGISTAR_MATTER_TITLE]),
+                title=str_simplified(legistar_ev[LEGISTAR_MATTER_TITLE]),
                 result_status=self.get_matter_status(
                     legistar_ev[LEGISTAR_MATTER_STATUS]
                 ),
@@ -836,7 +845,7 @@ class LegistarScraper:
         return self.get_none_if_empty(
             MinutesItem(
                 external_source_id=legistar_ev_item[LEGISTAR_MINUTE_EXT_ID],
-                name=stripped(legistar_ev_item[LEGISTAR_MINUTE_NAME]),
+                name=str_simplified(legistar_ev_item[LEGISTAR_MINUTE_NAME]),
             )
         )
 
